========================
Graphical User Interface
========================

In this chapter,
we briefly discuss the main functions of the graphical user interface (GUI).
A more detailed description of the functionality that lies behind the GUI
can be found in the :doc:`filters documentation <../pkg/filters>`.

The main GUI should look something similar to this:

.. image:: ../figures/gui_main_window.png
  :width: 600
  :alt: Main Window

Here, a file is already loaded and all buttons in the toolbar are active.
The window title shows the current version of the ``rimseval`` package
that is used in the GUI. The menu bar and tool bar below
present all functions.
If you browse through the menu bar you will see that many more functions
are available than can be seen in the tool bar.
In the toolbar, only the most frequently used functions are made available.

Below the tool bar,
the GUI has three sections.
On the left is the file dialog,
which indicates what files are open.
The file indicated with a green tick is the one
that is currently active.
Double-click one of the other names to activate that file.
The center pane shows the possible filters that are available.
Hovering over individual filters will show tool tips on what they do.
Finally, the right side shows the integrals of defined peaks
and the associated uncertainties.

At the bottom of the GUI is the status bar.
Here, helpful information will be displayed when you hover over tool bar buttons.

All functions of the GUI contain tool tips,
so hover with your mouse over buttons and dials,
and some help should be displayed.
